#
# spec file for package libpsl
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2015 rpm@cicku.me
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define somajor 5
Name:           libpsl
Version:        0.14.0
Release:        1.2
Summary:        C library for the Publix Suffix List
License:        MIT
Group:          Development/Libraries/C and C++
Url:            https://rockdaboot.github.io/libpsl
Source:         https://github.com/rockdaboot/libpsl/releases/download/%{name}-%{version}/%{name}-%{version}.tar.gz
Source1000:     baselibs.conf
BuildRequires:  pkgconfig >= 0.9.0
BuildRequires:  publicsuffix
BuildRequires:  python-base >= 2.7
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{?suse_version} > 1110
BuildRequires:  libicu-devel
%endif
%if %{with gtk-doc}
BuildRequires:  gtk-doc >= 1.15
%endif

%description
libpsl is a C library to handle the Public Suffix List. A "public suffix" is a
domain name under which Internet users can directly register own names.

HTTP user agents can use it to avoid privacy-leaking "supercookies" and "super
domain" certificates. It is also use do highlight domain parts in a user interface
and sorting domain lists by site.

%package -n %{name}%{somajor}
Summary:        C library for the Publix Suffix List
Group:          System/Libraries

%description -n %{name}%{somajor}
libpsl is a C library to handle the Public Suffix List. A "public suffix" is a
domain name under which Internet users can directly register own names.

HTTP user agents can use it to avoid privacy-leaking "supercookies" and "super
domain" certificates. It is also use do highlight domain parts in a user interface
and sorting domain lists by site.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name}%{somajor} = %{version}
Requires:       publicsuffix

%description    devel
libpsl is a C library to handle the Public Suffix List. A "public suffix" is a
domain name under which Internet users can directly register own names.

HTTP user agents can use it to avoid privacy-leaking "supercookies" and "super
domain" certificates. It is also use do highlight domain parts in a user interface
and sorting domain lists by site.

This package contains libraries and header files.

%package -n     psl
Summary:        Commandline utility to explore the Public Suffix List
Group:          Productivity/Networking/Other

%description -n psl
This package contains a commandline utility to explore the Public Suffix List,
for example it checks if domains are public suffixes, checks if cookie-domain
is acceptable for domains and so on.

HTTP user agents can use it to avoid privacy-leaking "supercookies" and "super
domain" certificates. It is also use do highlight domain parts in a user interface
and sorting domain lists by site.

%prep
%setup -q

%build
%configure \
	--disable-silent-rules \
	--disable-static \
%if 0%{?suse_version} <= 1110
	--disable-runtime \
	--disable-builtin \
%endif
	--with-psl-file=%{_datadir}/publicsuffix/public_suffix_list.dat

make %{?_smp_mflags}

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
make DESTDIR=%{buildroot} install-man
find %{buildroot} -type f -name "*.la" -delete -print

%check
make %{?_smp_mflags} check || cat tests/test-suite.log

%post -n %{name}%{somajor} -p /sbin/ldconfig
%postun -n %{name}%{somajor} -p /sbin/ldconfig

%files -n %{name}%{somajor}
%defattr(-,root,root)
%doc COPYING
%{_libdir}/libpsl.so.%{somajor}*

%files devel
%defattr(-,root,root)
%doc AUTHORS NEWS COPYING
%{_includedir}/libpsl.h
%{_libdir}/libpsl.so
%{_libdir}/pkgconfig/libpsl.pc
%if %{with gtk-doc}
%{_datadir}/gtk-doc/html/libpsl/
%endif

%files -n psl
%defattr(-,root,root)
%doc AUTHORS NEWS COPYING
%{_bindir}/psl

%changelog
* Mon Aug  1 2016 astieger@suse.com
- libpsl 0.14.0:
  * Remove unneeded libraries from tools/psl link step
  * Use https instead of http where possible
  * Add man page for tools/psl
  * Add header magic to DAFSA files
  * Rename make_dafsa.py to psl-make-dafsa
  * Add man page for psl-make-dafsa
* Wed Mar  9 2016 astieger@suse.com
- libpsl 0.13.0:
  * Use tests.txt as PSL test file by default
  * Slightly shorter DAFSA array when sorting input
  * Check for python 2.7+ in configure.ac
  * Fix python3 incompatibilities in make_dafsa.py
* Fri Feb  5 2016 idonmez@suse.com
- Add baselibs.conf
* Thu Jan  7 2016 astieger@suse.com
- libpsl 0.12.0 (libpsl.so.5 5:0:0)
  * Remove psl_builtin_compile_time()
  * Add function psl_is_public_suffix2()
  * Avoid libicu dependency with --enable-runtime=no
- drop upstreamed 0001-Remove-include-of-bits-stat.h.patch
* Sat Nov 28 2015 astieger@suse.com
- fix SLE 11 build:
  * adding 0001-Remove-include-of-bits-stat.h.patch
  * skip IDN feature
- update descriptions and categories
* Sun Nov 15 2015 astieger@suse.com
- initial package for libpsl based on Fedora Spec
